@@ -21,22 +21,20 @@ http://www.gnu.org/copyleft */
 #ifndef __ERROR_H
 #define __ERROR_H
 
-typedef struct source_line_t
-{
-  char *file_name;
-  int include_p;
-  int number;
-}
-SRC_LINE;
+typedef struct source_line_t {
+    char *file_name;
+    int include_p;
+    int number;
+} SRC_LINE;
 
 extern SRC_LINE no_line;
 #define is_no_line_p(L) ((L).number <= 0)
 
-void remark (SRC_LINE line, char *fmt, ...);
-void warn (SRC_LINE line, char *fmt, ...);
-void err (SRC_LINE line, char *fmt, ...);
-void die (SRC_LINE line, char *fmt, ...);
-int trouble_p (void);
-void report_errors (void);
+void remark(SRC_LINE line, char *fmt, ...);
+void warn(SRC_LINE line, char *fmt, ...);
+void err(SRC_LINE line, char *fmt, ...);
+void die(SRC_LINE line, char *fmt, ...);
+int trouble_p(void);
+void report_errors(void);
 
 #endif
