@@ -496,6 +496,36 @@ void do_cos(EXPR_VAL * r, EXPR_VAL * a, SRC_LINE line)
     }
 }
 
+void do_asin(EXPR_VAL * r, EXPR_VAL * a, SRC_LINE line)
+{
+    switch (a->tag) {
+    case E_FLOAT:
+	if (-1 < a->val.flt || a->val.flt > 1)
+	    err(line, "asin operand is out of range [-1..1]");
+	set_float(r, (180 / PI) * asin(a->val.flt));
+	break;
+    default:
+	err(line, "operand of asin (type %s) must be float",
+	    expr_val_type_str[a->tag]);
+	break;
+    }
+}
+
+void do_acos(EXPR_VAL * r, EXPR_VAL * a, SRC_LINE line)
+{
+    switch (a->tag) {
+    case E_FLOAT:
+	if (-1 < a->val.flt || a->val.flt > 1)
+	    err(line, "asin operand is out of range [-1..1]");
+	set_float(r, (180 / PI) * acos(a->val.flt));
+	break;
+    default:
+	err(line, "operand of acos (type %s) must be float",
+	    expr_val_type_str[a->tag]);
+	break;
+    }
+}
+
 void do_atan2(EXPR_VAL * r, EXPR_VAL * a, EXPR_VAL * b, SRC_LINE line)
 {
     switch (HASH(a->tag, b->tag)) {
