@@ -45,42 +45,39 @@ http://www.gnu.org/copyleft */
 // this must match string table in global.c
 extern char *output_language_str[];
 
-typedef struct global_env_t
-{
-  unsigned set_p_mask;
-  OPTS opts[1];
-  POINT_3D bb1, bb2;		// bounding box 
-  char *frame_opts;		// null if frame has none
-  FLOAT baseline;
-  int split_p;
-  TRANSFORM camera;
-  int output_language;
-  PST_VERSION pst_version[1];
-  TIKZ_VERSION tikz_version[1];
-}
-GLOBAL_ENV;
+typedef struct global_env_t {
+    unsigned set_p_mask;
+    OPTS opts[1];
+    POINT_3D bb1, bb2;		// bounding box 
+    char *frame_opts;		// null if frame has none
+    FLOAT baseline;
+    int split_p;
+    TRANSFORM camera;
+    int output_language;
+    PST_VERSION pst_version[1];
+    TIKZ_VERSION tikz_version[1];
+} GLOBAL_ENV;
 
 #define global_env_is_set_p(Env, F) ((Env)->set_p_mask & bit(F))
 
-void init_global_env (GLOBAL_ENV * env, PST_VERSION *pst_version, TIKZ_VERSION *tikz_version);
-void set_global_baseline (GLOBAL_ENV * env, FLOAT baseline, SRC_LINE line);
+void init_global_env(GLOBAL_ENV * env, PST_VERSION * pst_version,
+		     TIKZ_VERSION * tikz_version);
+void set_global_baseline(GLOBAL_ENV * env, FLOAT baseline, SRC_LINE line);
 #define NO_BASELINE FLT_MAX
-void set_global_env_extent (GLOBAL_ENV * env, POINT_3D p1, POINT_3D p2,
-			    SRC_LINE line);
-int get_transformed_global_env_extent (BOX_3D * extent, GLOBAL_ENV * env);
-void set_global_env_opts (GLOBAL_ENV * env, char *opt_str, SRC_LINE line);
-void set_global_env_frame (GLOBAL_ENV * env, char *opt_str, SRC_LINE line);
-void set_global_env_camera (GLOBAL_ENV * env, TRANSFORM camera,
-			    SRC_LINE line);
-void set_global_output_language (GLOBAL_ENV * env, int output_language,
-				 SRC_LINE line);
-int get_global_output_language (int *output_language, GLOBAL_ENV * env);
-int cmp_with_global_pst_version(GLOBAL_ENV * env,
-				char * version_str, 
+void set_global_env_extent(GLOBAL_ENV * env, POINT_3D p1, POINT_3D p2,
+			   SRC_LINE line);
+int get_transformed_global_env_extent(BOX_3D * extent, GLOBAL_ENV * env);
+void set_global_env_opts(GLOBAL_ENV * env, char *opt_str, SRC_LINE line);
+void set_global_env_frame(GLOBAL_ENV * env, char *opt_str, SRC_LINE line);
+void set_global_env_camera(GLOBAL_ENV * env, TRANSFORM camera,
+			   SRC_LINE line);
+void set_global_output_language(GLOBAL_ENV * env, int output_language,
 				SRC_LINE line);
+int get_global_output_language(int *output_language, GLOBAL_ENV * env);
+int cmp_with_global_pst_version(GLOBAL_ENV * env,
+				char *version_str, SRC_LINE line);
 int cmp_with_global_tikz_version(GLOBAL_ENV * env,
-				 char * version_str, 
-				 SRC_LINE line);
+				 char *version_str, SRC_LINE line);
 
 extern GLOBAL_ENV __the_global_env[1];
 
