@@ -21,45 +21,38 @@ http://www.gnu.org/copyleft */
 #include <stdio.h>
 #include "memutil.h"
 
-void *
-safe_malloc (unsigned size)
+void *safe_malloc(unsigned size)
 {
 #undef malloc
-  void *p = malloc (size);
-  if (size > 0 && p == NULL)
-    {
-      fprintf (stderr, "\nsafe_malloc: out of memory\n");
-      exit (1);
+    void *p = malloc(size);
+    if (size > 0 && p == NULL) {
+	fprintf(stderr, "\nsafe_malloc: out of memory\n");
+	exit(1);
     }
-  return p;
+    return p;
 }
 
-void *
-safe_realloc (void *p, unsigned size)
+void *safe_realloc(void *p, unsigned size)
 {
 #undef realloc
-  void *q = realloc (p, size);
-  if (size > 0 && q == NULL)
-    {
-      fprintf (stderr, "\nsafe_realloc: out of memory\n");
-      exit (1);
+    void *q = realloc(p, size);
+    if (size > 0 && q == NULL) {
+	fprintf(stderr, "\nsafe_realloc: out of memory\n");
+	exit(1);
     }
-  return q;
+    return q;
 }
 
-char *
-safe_strdup (char *str)
+char *safe_strdup(char *str)
 {
 #undef strdup
-  char *new_str = safe_malloc (strlen (str) + 1);
-  strcpy (new_str, str);
-  return new_str;
+    char *new_str = safe_malloc(strlen(str) + 1);
+    strcpy(new_str, str);
+    return new_str;
 }
 
-void
-safe_free (void *p)
+void safe_free(void *p)
 {
 #undef free
-  free (p);
+    free(p);
 }
-
