@@ -45,57 +45,59 @@ http://www.gnu.org/copyleft */
 #define OPT_EMIT_VAL		0x80
 
 // some dynamic array types
-typedef struct opt_t
-{
-  char *key, *val;
-}
-OPT;
+typedef struct opt_t {
+    char *key, *val;
+} OPT;
 
-typedef struct opt_list_t
-{
-  DYNAMIC_ARRAY_FIELDS (OPT, elt, n_elts);
-}
-OPT_LIST;
+typedef struct opt_list_t {
+    DYNAMIC_ARRAY_FIELDS(OPT, elt, n_elts);
+} OPT_LIST;
 
-DECLARE_DYNAMIC_ARRAY_PROTOS (OPT_LIST, OPT, opt_list, elt, n_elts)
+DECLARE_DYNAMIC_ARRAY_PROTOS(OPT_LIST, OPT, opt_list, elt, n_elts);
 
-typedef struct opts_t
-{
-  // DEBUG: could cache list data here for speed
-  OPT_LIST list[1];
-}
-OPTS;
+#define OPTS_LAY 0
+#define LAY_IN  0
+#define LAY_OVER 1
+#define LAY_UNDER -1
 
-void init_opts (OPTS * opts);
-void setup_opts (OPTS * opts, char *opt_str, SRC_LINE line);
-OPTS *raw_opts (void);
-OPTS *new_opts (char *opts_str, SRC_LINE line);
-void clear_opts (OPTS * opts);
-char *opt_val (OPTS * opts, char *opt);
-int bool_opt_p (OPTS * opts, char *opt, int default_p);
-int opt_type (OPT * opt, int default_type, int lang);
-void add_no_edges_default_opt (OPTS ** opts_ptr, int lang);
-void add_solid_white_default_opt (OPTS ** opts_ptr, int lang);
+typedef struct opts_t {
+    OPT_LIST list[1];
+
+    // Cached values.
+    unsigned long set_p_mask;
+    int lay;
+} OPTS;
+
+void init_opts(OPTS * opts);
+void setup_opts(OPTS * opts, char *opt_str, SRC_LINE line);
+OPTS *raw_opts(void);
+OPTS *new_opts(char *opts_str, SRC_LINE line);
+void clear_opts(OPTS * opts);
+char *opt_val(OPTS * opts, char *opt);
+int bool_opt_p(OPTS * opts, char *opt, int default_p);
+int opt_type(OPT * opt, int default_type, int lang);
+void add_no_edges_default_opt(OPTS ** opts_ptr, int lang);
+void add_solid_white_default_opt(OPTS ** opts_ptr, int lang);
 // selective copy for splitting option lists by type
-OPTS *copy_opts (OPTS * opts, int type_mask, int lang);
-OPTS *cat_opts (OPTS * dst, OPTS * src);
+OPTS *copy_opts(OPTS * opts, int type_mask, int lang);
+OPTS *cat_opts(OPTS * dst, OPTS * src);
 // selective copy for splitting out line options and modifying arrows
-OPTS *copy_line_opts (OPTS * opts, int first_p, int last_p, int lang);
-void emit_opts_raw (FILE * f, OPTS * opts, int lang);
-void emit_opts (FILE * f, OPTS * opts, int lang);
-void emit_opts_with_exceptions (FILE * f, OPTS * opts, char ** exceptions, int lang);
-void check_opts (OPTS * opts,
-		 int allowed, char *allowed_msg, int lang,
-		 SRC_LINE line);
+OPTS *copy_line_opts(OPTS * opts, int first_p, int last_p, int lang);
+void emit_opts_raw(FILE * f, OPTS * opts, int lang);
+void emit_opts(FILE * f, OPTS * opts, int lang);
+void emit_opts_with_exceptions(FILE * f, OPTS * opts, char **exceptions,
+			       int lang);
+void check_opts(OPTS * opts, int allowed, char *allowed_msg, int lang,
+		SRC_LINE line);
 
 // slice src into dest using Perl/Python conventions
-char *str_slice (char *dst, int dst_size, char *src, int beg, int end);
+char *str_slice(char *dst, int dst_size, char *src, int beg, int end);
 #define SLICE_TO_END  ((int)(~0u >> 1))
 
 // find last occurance of aachar in set in src; return index or -1 if none
-int str_last_occurance (char *src, char *set);
+int str_last_occurance(char *src, char *set);
 
 // strtok with a state variable instead of static
-char *istrtok (int *p, char *s, char sep);
-     
+char *istrtok(int *p, char *s, char sep);
+
 #endif
