@@ -25,6 +25,9 @@ http://www.gnu.org/copyleft */
 #include "error.h"
 #include "symbol.h"
 
+/* Skip yyunput() as we don't use it. */
+#define YY_NO_UNPUT
+
 extern int yydebug;
 extern SRC_LINE line;
 extern GLOBAL_ENV parsed_global_env[1];
