@@ -57,21 +57,23 @@
      VIEW = 283,
      SQRT = 284,
      SIN = 285,
-     COS = 286,
-     ATAN2 = 287,
-     UNIT = 288,
-     INVERSE = 289,
-     GLOBAL = 290,
-     SET = 291,
-     PICTUREBOX = 292,
-     FRAME = 293,
-     CAMERA = 294,
-     LANGUAGE = 295,
-     PSTRICKS = 296,
-     TIKZ = 297,
-     LaTeX = 298,
-     ConTeXt = 299,
-     NEG = 300
+     ASIN = 286,
+     COS = 287,
+     ACOS = 288,
+     ATAN2 = 289,
+     UNIT = 290,
+     INVERSE = 291,
+     GLOBAL = 292,
+     SET = 293,
+     PICTUREBOX = 294,
+     FRAME = 295,
+     CAMERA = 296,
+     LANGUAGE = 297,
+     PSTRICKS = 298,
+     TIKZ = 299,
+     LaTeX = 300,
+     ConTeXt = 301,
+     NEG = 302
    };
 #endif
 /* Tokens.  */
@@ -103,21 +105,23 @@
 #define VIEW 283
 #define SQRT 284
 #define SIN 285
-#define COS 286
-#define ATAN2 287
-#define UNIT 288
-#define INVERSE 289
-#define GLOBAL 290
-#define SET 291
-#define PICTUREBOX 292
-#define FRAME 293
-#define CAMERA 294
-#define LANGUAGE 295
-#define PSTRICKS 296
-#define TIKZ 297
-#define LaTeX 298
-#define ConTeXt 299
-#define NEG 300
+#define ASIN 286
+#define COS 287
+#define ACOS 288
+#define ATAN2 289
+#define UNIT 290
+#define INVERSE 291
+#define GLOBAL 292
+#define SET 293
+#define PICTUREBOX 294
+#define FRAME 295
+#define CAMERA 296
+#define LANGUAGE 297
+#define PSTRICKS 298
+#define TIKZ 299
+#define LaTeX 300
+#define ConTeXt 301
+#define NEG 302
 
 
 
@@ -138,7 +142,7 @@ typedef union YYSTYPE {
   int index;
 } YYSTYPE;
 /* Line 1447 of yacc.c.  */
-#line 142 "y.tab.h"
+#line 146 "y.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
